@@ -1,7 +1,5 @@
-// -*- Mode: C++; indent-tabs-mode: nil; c-basic-offset: 4 -*-
-
 /*
- * PaperBox - document-tag-cloud-model.cc
+ * Paperbox - document-tag-cloud-model.cc
  *
  * Copyright (C) 2007 Marko Anastasov
  *
@@ -28,7 +26,7 @@
 namespace paperbox {
 
     using std::vector;
-    using boost::shared_ptr;
+    using std::tr1::shared_ptr;
 
     DocumentTagCloudModel::DocumentTagCloudModel(int min_font_size,
                                                  int max_font_size)
